"""Functions to convert different structures / objects"""

from .dictionary import basedict, dict2str
from .error import err2str
from .temporality import (
    secs2unit,
    dt2ts,
    ts2dt,
    str2dt,
)
